pub fn delete_dist(dir: PathBuf) -> Result<(), ExecutionError>Expand description
Deletes the entire dist/ directory. Notably, this is where we keep
several Cargo artifacts, so this means the next build will be much
slower.
pub fn delete_dist(dir: PathBuf) -> Result<(), ExecutionError>Deletes the entire dist/ directory. Notably, this is where we keep
several Cargo artifacts, so this means the next build will be much
slower.