Enum perseus_cli::parse::Subcommand
source · [−]pub enum Subcommand {
Build(BuildOpts),
ExportErrorPage(ExportErrorPageOpts),
Export(ExportOpts),
Serve(ServeOpts),
Test(ServeOpts),
Clean(CleanOpts),
Eject,
Deploy(DeployOpts),
Prep,
Tinker(TinkerOpts),
Snoop(SnoopSubcommand),
}Variants
Build(BuildOpts)
ExportErrorPage(ExportErrorPageOpts)
Export(ExportOpts)
Serve(ServeOpts)
Test(ServeOpts)
Serves your app as perseus serve does, but puts it in testing mode
Clean(CleanOpts)
Eject
Ejects you from the CLI harness, enabling you to work with the internals of Perseus
Deploy(DeployOpts)
Prep
Prepares the .perseus/ directory (done automatically by build and serve)
Tinker(TinkerOpts)
Snoop(SnoopSubcommand)
Runs one of the underlying commands that builds your app, allowing you to see more detailed logs