Struct perseus_cli::parse::CheckOpts
source · [−]Fields
watch: boolWatch the files in your working directory for changes (exluding
target/ and dist/)
custom_watch: Vec<String>Marks a specific file/directory to be watched (directories will be recursively watched)
generate: boolMake sure the app’s page generation works properly (this will take much longer, but almost guarantees that your app will actually build); use this to catch errors in build state and the like