Struct perseus_cli::parse::TinkerOpts
source · [−]Expand description
Runs the tinker action of plugins, which lets them modify the Perseus engine
Fields
no_clean: boolDon’t remove and recreate the .perseus/ directory
force: boolForce this command to run, even if you’ve ejected (this may result in some or all of your changes being removed, it depends on the plugins you’re using)