Function perseus_cli::snoop_server [−][src]
pub fn snoop_server(dir: PathBuf) -> Result<i32, ExecutionError>Expand description
Runs the commands to run the server directly so the user can see detailed logs.
pub fn snoop_server(dir: PathBuf) -> Result<i32, ExecutionError>Runs the commands to run the server directly so the user can see detailed logs.