Struct perseus_cli::parse::ServeOpts
source · [−]pub struct ServeOpts {
pub no_run: bool,
pub no_build: bool,
pub release: bool,
pub standalone: bool,
pub integration: Integration,
pub watch: bool,
pub host: String,
pub port: u16,
}Expand description
Serves your app (set the $HOST and $PORT environment variables to change the location it’s served at)
Fields
no_run: boolDon’t run the final binary, but print its location instead as the last line of output
no_build: boolOnly build the server, and use the results of a previous perseus build
release: boolBuild and serve for production
standalone: boolMake the final binary standalone (this is used in perseus deploy only, don’t manually invoke it unless you have a good reason!)
integration: IntegrationThe server integration to use
watch: boolWatch the files in your working directory for changes (exluding target/ and .perseus/)
host: StringWhere to host your exported app
port: u16The port to host your exported app on